import { attachShadow, h, proxyCustomElement } from '@stencil/core/internal/client';
export { setAssetPath, setPlatformOptions } from '@stencil/core/internal/client';

function format(first, middle, last) {
  return (first || '') + (middle ? ` ${middle}` : '') + (last ? ` ${last}` : '');
}
function capitalize(string) {
  return string.charAt(0).toUpperCase() + string.slice(1);
}

const leanButtonCss = ".btn{background-color:var(--cl-main)}";

const LeanButton$1 = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    attachShadow(this);
  }
  render() {
    return h("button", { class: "btn" }, capitalize(this.label));
  }
  static get style() { return leanButtonCss; }
};

const leanListCss = ":host{display:block}";

const LeanList$1 = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    attachShadow(this);
  }
  render() {
    return (h("ul", null, h("h1", null, capitalize(this.title)), h("slot", null)));
  }
  static get style() { return leanListCss; }
};

const myComponentCss = ":host{display:block}";

const MyComponent$1 = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    attachShadow(this);
  }
  getText() {
    return format(this.first, this.middle, this.last);
  }
  render() {
    return h("div", null, "Hello, World! I'm ", this.getText());
  }
  static get style() { return myComponentCss; }
};

const LeanButton = /*@__PURE__*/proxyCustomElement(LeanButton$1, [1,"lean-button",{"label":[1]}]);
const LeanList = /*@__PURE__*/proxyCustomElement(LeanList$1, [1,"lean-list",{"title":[1]}]);
const MyComponent = /*@__PURE__*/proxyCustomElement(MyComponent$1, [1,"my-component",{"first":[1],"middle":[1],"last":[1]}]);
const defineCustomElements = (opts) => {
  if (typeof customElements !== 'undefined') {
    [
      LeanButton,
  LeanList,
  MyComponent
    ].forEach(cmp => {
      if (!customElements.get(cmp.is)) {
        customElements.define(cmp.is, cmp, opts);
      }
    });
  }
};

export { LeanButton, LeanList, MyComponent, defineCustomElements };
